Programs

Struct Programs 

pub struct Programs {
    pub programs: Option<Vec<Program>>,
}
Programs : The base response type of the getOptedInPrograms method.

Fields

programs: Option<Vec<Program>>

An array of seller programs that the seller’s account is opted in to. An empty array is returned if the seller is not opted in to any of the seller programs.

Implementations

Source

impl Programs

pub fn new() -> Programs

The base response type of the getOptedInPrograms method.