pub struct CustomPolicyCreateRequest {
pub description: Option<String>,
pub label: Option<String>,
pub name: Option<String>,
pub policy_type: Option<String>,
}Expand description
CustomPolicyCreateRequest : This type is used by the request payload of the createCustomPolicy method to define a new custom policy for a specific marketplace.
Fields
description: Option<String>Contains the seller’s policy and policy terms.
Max length: 15,000
label: Option<String>Customer-facing label shown on View Item pages for items to which the policy applies. This seller-defined string is displayed as a system-generated hyperlink pointing to the seller’s policy information.
Max length: 65
name: Option<String>The seller-defined name for the custom policy. Names must be unique for policies assigned to the same seller and policy type.
<span class="tablenote">Note: This field is visible only to the seller.
Max length: 65
policy_type: Option<String>Specifies the type of custom policy being created.
Two Custom Policy types are supported:
- Product Compliance (PRODUCT_COMPLIANCE)
- Takeback (TAKE_BACK)
Implementations
Sourceimpl CustomPolicyCreateRequest
impl CustomPolicyCreateRequest
Sourcepub fn new() -> CustomPolicyCreateRequest
pub fn new() -> CustomPolicyCreateRequest
This type is used by the request payload of the createCustomPolicy method to define a new custom policy for a specific marketplace.