Error

Struct Error 

pub struct Error {
    pub category: Option<String>,
    pub domain: Option<String>,
    pub error_id: Option<i32>,
    pub input_ref_ids: Option<Vec<String>>,
    pub long_message: Option<String>,
    pub message: Option<String>,
    pub output_ref_ids: Option<Vec<String>>,
    pub parameters: Option<Vec<ErrorParameter>>,
    pub subdomain: Option<String>,
}
Error : Type that defines the fields that can be returned in an error.

Fields

category: Option<String>

Identifies whether the error was in the REQUEST or happened when running the APPLICATION.

domain: Option<String>

The primary system where the error occurred. This is relevant for application errors. For Analytics errors, it always has the value API_ANALYTICS.

error_id: Option<i32>

A positive integer that uniquely identifies the specific error condition that occurred. Your application can use error codes as identifiers in your customized error-handling algorithms. Traffic report error IDs range from 50001 to 50500.

input_ref_ids: Option<Vec<String>>

Identifies specific request elements associated with the error, if any. inputRefId’s response is format specific. For JSON, use JSONPath notation.

long_message: Option<String>

A more detailed explanation of the error than given in the message error field.

message: Option<String>

Information on how to correct the problem, in the end user’s terms and language where applicable. Its value is at most 50 characters long. If applicable, the value is localized in the end user’s requested locale.

output_ref_ids: Option<Vec<String>>

Identifies specific response elements associated with the error, if any. Path format is the same as inputRefId.

parameters: Option<Vec<ErrorParameter>>

This optional list of name/value pairs that contain context-specific ErrorParameter objects, with each item in the list being a parameter (or input field name) that caused an error condition. Each ErrorParameter object consists of two fields, a name and a value.

subdomain: Option<String>

If present, indicates which subsystem in which the error occurred.

Implementations

Source

impl Error

pub fn new() -> Error

Type that defines the fields that can be returned in an error.