Definition

Struct Definition 

pub struct Definition {
    pub data_type: Option<String>,
    pub key: Option<String>,
    pub localized_name: Option<String>,
}
Definition : A complex type that defines a dimension key and metrics in a traffic report.

Fields

data_type: Option<String>

Indicates the data type of the returned dimension. For example, if the dimension is day, the data type is DATE. For implementation help, refer to eBay API documentation

key: Option<String>

The value the dimension or metric parameter as submitted in the request.

localized_name: Option<String>

The localized name of the metric or dimension (translated into the language specified in the Accept-Language HTTP request header). For example, if Accept-Language is set to de-DE, the value "day" in the dimension container is returned as "tag", and a metric of TRANSACTION is returned as "Transaktionsanzahl".

Implementations

Source

impl Definition

pub fn new() -> Definition

A complex type that defines a dimension key and metrics in a traffic report.