Distribution

Struct Distribution 

pub struct Distribution {
    pub name: Option<String>,
    pub value: Option<String>,
}
Distribution : This complex type defines of a piece of data that is grouped by the associated basis. It contains the name for the data set and its associated value.

Fields

name: Option<String>

The name of a distribution in which the seller is active.

value: Option<String>

This field contains the number of transactions the seller had in the distribution (identified by the associated name field) during the metric evaluationCycle.

Implementations

Source

impl Distribution

pub fn new() -> Distribution

This complex type defines of a piece of data that is grouped by the associated basis. It contains the name for the data set and its associated value.