pub struct MetadataRecord {
pub metadata_values: Option<Vec<Value>>,
pub value: Option<Box<Value>>,
}Expand description
MetadataRecord : A complex type that defines the data records returned in the report.
Fields
metadata_values: Option<Vec<Value>>A list of data in a row returned in the traffic report. The data in each of the cells match the labels in headers of the report.
value: Option<Box<Value>>Implementations
Sourceimpl MetadataRecord
impl MetadataRecord
Sourcepub fn new() -> MetadataRecord
pub fn new() -> MetadataRecord
A complex type that defines the data records returned in the report.