Record

Struct Record 

pub struct Record {
    pub dimension_values: Option<Vec<Value>>,
    pub metric_values: Option<Vec<Value>>,
}
Record : Type that defines the fields of the individual record of the report.

Fields

dimension_values: Option<Vec<Value>>

A list where each element contains either the string DAY (if the dimension is DAY), or the listing ID for which the record’s metric data is computed. A second array member, applicable, is always true for dimension values.

metric_values: Option<Vec<Value>>

A list where each element contains a value field that indicates the record’s value for the metric. Each element also contains an applicable field that indicates the veracity of the computed value.

Note that there are no metric names or IDs associated with the values returned in this array. The metadata to which these values relate can be found in the key values in metadataKeys. The order of the metric values in this array equals the order of the key values in metadataHeader.

Implementations

Source

impl Record

pub fn new() -> Record

Type that defines the fields of the individual record of the report.