Report

Struct Report 

pub struct Report {
    pub dimension_metadata: Option<Vec<Metadata>>,
    pub end_date: Option<String>,
    pub header: Option<Box<Header>>,
    pub last_updated_date: Option<String>,
    pub records: Option<Vec<Record>>,
    pub start_date: Option<String>,
    pub warnings: Option<Vec<Error>>,
}
Report : The complex type that defines that defines the report.

Fields

dimension_metadata: Option<Vec<Metadata>>

A complex type containing the header of the report and the type of data containted in the rows of the report.

end_date: Option<String>



The time stamp is formatted as an <a href="https://www.iso.org/iso-8601-date-and-time-format.html" target="_blank">ISO 8601 string, which is based on the 24-hour Universal Coordinated Time (UTC) clock.

If you specify an end date that is beyond the <a href="#response.lastUpdatedDate">lastUpdatedDate value, eBay returns a report that contains data only up to the lastUpdateDate date.

Format: [YYYY]-[MM]-[DD]T[hh]:[mm]:[ss].[sss]Z
Example: 2018-08-20T07:09:00.000Z

header: Option<Box<Header>>last_updated_date: Option<String>

The date and time, in ISO 8601 format, that indicates the last time the data returned in the report was updated.

records: Option<Vec<Record>>

A complex type containing the individual data records for the traffic report.

start_date: Option<String>

The start date of the date range used to calculate the report, in ISO 8601 format.

warnings: Option<Vec<Error>>

An array of any process errors or warnings that were generated during the processing of the call processing.

Implementations

Source

impl Report

pub fn new() -> Report

The complex type that defines that defines the report.