pub struct AuthenticityGuaranteeProgram {
pub description: Option<String>,
pub terms_web_url: Option<String>,
}Expand description
AuthenticityGuaranteeProgram : A type that identifies whether the item is qualified for the Authenticity Guarantee program.
Fields
description: Option<String>An indication that the item is qualified for the Authenticity Guarantee program.
terms_web_url: Option<String>The URL to the Authenticity Guarantee program terms of use.
Implementations
Sourceimpl AuthenticityGuaranteeProgram
impl AuthenticityGuaranteeProgram
Sourcepub fn new() -> AuthenticityGuaranteeProgram
pub fn new() -> AuthenticityGuaranteeProgram
A type that identifies whether the item is qualified for the Authenticity Guarantee program.