pub struct AuthenticityVerificationProgram {
pub description: Option<String>,
pub terms_web_url: Option<String>,
}Expand description
AuthenticityVerificationProgram : A type that identifies whether the item is from a verified seller.
Fields
description: Option<String>An indication that the item is from a verified seller.
terms_web_url: Option<String>The URL to the Authenticity Verification program terms of use.
Implementations
Sourceimpl AuthenticityVerificationProgram
impl AuthenticityVerificationProgram
Sourcepub fn new() -> AuthenticityVerificationProgram
pub fn new() -> AuthenticityVerificationProgram
A type that identifies whether the item is from a verified seller.