pub struct Refinement {
pub aspect_distributions: Option<Vec<AspectDistribution>>,
pub dominant_category_id: Option<String>,
}Expand description
Refinement : This type identifies a product category and the aspects associated with that category. Each aspect distribution container returns the distribution of values that have been used for the aspect.
Fields
aspect_distributions: Option<Vec<AspectDistribution>>Contains information about one or more aspects that are associated with the category identified by dominantCategoryId.
dominant_category_id: Option<String>The ID of the category that eBay determines is most likely to cover the products matching the search criteria.
Implementations
Sourceimpl Refinement
impl Refinement
Sourcepub fn new() -> Refinement
pub fn new() -> Refinement
This type identifies a product category and the aspects associated with that category. Each aspect distribution container returns the distribution of values that have been used for the aspect.