pub struct Error {
pub category: Option<String>,
pub domain: Option<String>,
pub error_id: Option<i32>,
pub input_ref_ids: Option<Vec<String>>,
pub long_message: Option<String>,
pub message: Option<String>,
pub output_ref_ids: Option<Vec<String>>,
pub parameters: Option<Vec<ErrorParameter>>,
pub subdomain: Option<String>,
}Expand description
Error : This type defines the fields that can be returned in an error.
Fields
category: Option<String>Identifies the type of erro.
domain: Option<String>Name for the primary system where the error occurred. This is relevant for application errors.
error_id: Option<i32>A unique number to identify the error.
input_ref_ids: Option<Vec<String>>An array of request elements most closely associated to the error.
long_message: Option<String>A more detailed explanation of the error.
message: Option<String>Information on how to correct the problem, in the end user’s terms and language where applicable.
output_ref_ids: Option<Vec<String>>An array of request elements most closely associated to the error.
parameters: Option<Vec<ErrorParameter>>An array of name/value pairs that describe details the error condition. These are useful when multiple errors are returned.
subdomain: Option<String>Further helps indicate which subsystem the error is coming from. System subcategories include: Initialization, Serialization, Security, Monitoring, Rate Limiting, etc.