Error

Struct Error 

pub struct Error {
    pub category: Option<String>,
    pub domain: Option<String>,
    pub error_id: Option<i32>,
    pub input_ref_ids: Option<Vec<String>>,
    pub long_message: Option<String>,
    pub message: Option<String>,
    pub output_ref_ids: Option<Vec<String>>,
    pub parameters: Option<Vec<ErrorParameter>>,
    pub subdomain: Option<String>,
}
Error : This type is used to express detailed information on errors and warnings that may occur with a call request.

Fields

category: Option<String>

This string value indicates the error category. There are three categories of errors: request errors, application errors, and system errors.

domain: Option<String>

The name of the domain in which the error or warning occurred.

error_id: Option<i32>

A unique code that identifies the particular error or warning that occurred. Your application can use error codes as identifiers in your customized error-handling algorithms.

input_ref_ids: Option<Vec<String>>

An array of one or more reference IDs which identify the specific request element(s) most closely associated to the error or warning, if any.

long_message: Option<String>

A detailed description of the condition that caused the error or warning, and information on what to do to correct the problem.

message: Option<String>

A description of the condition that caused the error or warning.

output_ref_ids: Option<Vec<String>>

An array of one or more reference IDs which identify the specific response element(s) most closely associated to the error or warning, if any.

parameters: Option<Vec<ErrorParameter>>

Various warning and error messages return one or more variables that contain contextual information about the error or waring. This is often the field or value that triggered the error or warning.

subdomain: Option<String>

The name of the subdomain in which the error or warning occurred.

Implementations

Source

impl Error

pub fn new() -> Error

This type is used to express detailed information on errors and warnings that may occur with a call request.