pub struct ErrorParameter {
pub name: Option<String>,
pub value: Option<String>,
}Expand description
ErrorParameter : This type is used to indicate the parameter field/value that caused an issue with the call request.
Fields
name: Option<String>This type contains the name and value of an input parameter that contributed to a specific error or warning condition.
value: Option<String>This is the actual value that was passed in for the element specified in the name field.
Implementations
Sourceimpl ErrorParameter
impl ErrorParameter
Sourcepub fn new() -> ErrorParameter
pub fn new() -> ErrorParameter
This type is used to indicate the parameter field/value that caused an issue with the call request.