Address

Struct Address 

pub struct Address {
    pub address_line1: Option<String>,
    pub address_line2: Option<String>,
    pub city: Option<String>,
    pub country: Option<String>,
    pub county: Option<String>,
    pub postal_code: Option<String>,
    pub state_or_province: Option<String>,
}
Address : This type is used to define the physical address of an inventory location.

Fields

address_line1: Option<String>

The first line of a street address. This field is required for store and fulfillment center locations. A street address is not required for warehouse locations.

This field will be returned if defined for an inventory location.

Max length: 128

address_line2: Option<String>

The second line of a street address. This field can be used for additional address information, such as a suite or apartment number.

This field will be returned if defined for an inventory location.

Max length: 128

city: Option<String>

The city in which the inventory location resides. This field is required for store and fulfillment center locations. For warehouse locations, this field is conditionally required as part of a city and stateOrProvince pair if a postalCode is not provided. If a postalCode is provided, the city is derived from the provided postal code and this field is technically optional.

This field is returned if defined for an inventory location.

Max length: 128

country: Option<String>

The country in which the address resides, represented as two-letter <a href="https://www.iso.org/iso-3166-country-codes.html " title="https://www.iso.org " target="_blank">ISO 3166 country code. For example, US represents the United States, and DE represents Germany. For implementation help, refer to eBay API documentation

county: Option<String>

The county in which the address resides.

This field is returned if defined for an inventory location.

postal_code: Option<String>

The postal/zip code of the address. eBay uses postal codes to surface In-Store Pickup items within the vicinity of a buyer’s location, and it also uses postal codes (origin and destination) to estimate shipping costs when the seller uses calculated shipping. This field is required for store and fulfillment center locations.

For warehouse locations, this field is conditionally required if a city and stateOrProvince pair is not provided.

<span class="tablenote"> Note: For warehouse locations, city and stateOrProvince pair can be used instead of a postalCode value, and then the postal code is just derived from the city and state/province.

This field is returned if defined for an inventory location.

Max length: 16

state_or_province: Option<String>

The state/province in which the inventory location resides. This field is required for store and fulfillment center locations. For warehouse locations, this field is conditionally required as part of a city and stateOrProvince pair if a postalCode is not provided. If a postalCode is provided, the state or province is derived from the provided zip code and this field is technically optional.

Max length: 128

Implementations

Source

impl Address

pub fn new() -> Address

This type is used to define the physical address of an inventory location.