pub struct FormatAllocation {
pub auction: Option<i32>,
pub fixed_price: Option<i32>,
}Expand description
FormatAllocation : This type is used to indicate the quantities of the inventory items that are reserved for the different listing formats of the SKU offers.
Fields
auction: Option<i32>This integer value indicates the quantity of the inventory item that is reserved for the published auction format offers of the SKU.
fixed_price: Option<i32>This integer value indicates the quantity of the inventory item that is available for the fixed-price offers of the SKU.
Implementations
Sourceimpl FormatAllocation
impl FormatAllocation
Sourcepub fn new() -> FormatAllocation
pub fn new() -> FormatAllocation
This type is used to indicate the quantities of the inventory items that are reserved for the different listing formats of the SKU offers.