pub struct OfferKeyWithId {
pub offer_id: Option<String>,
}Expand description
OfferKeyWithId : This type is used by the getListingFees call to indicate the unpublished offer(s) for which expected listing fees will be retrieved. The user passes in one or more offerId values (a maximum of 250). See the <a href="https://pages.ebay.com/help/sell/fees.html " target="_blank">Standard selling fees help page for more information on listing fees.
Fields
offer_id: Option<String>The unique identifier of an unpublished offer for which expected listing fees will be retrieved. One to 250 offerId values can be passed in to the offers container for one getListingFees call.
Use the <a href="/api-docs/sell/inventory/resources/offer/methods/getOffers">getOffers method to retrieve offer IDs.
<span class="tablenote">Note: Errors will occur if offerId values representing published offers are passed in.
Implementations
Sourceimpl OfferKeyWithId
impl OfferKeyWithId
Sourcepub fn new() -> OfferKeyWithId
pub fn new() -> OfferKeyWithId
This type is used by the getListingFees call to indicate the unpublished offer(s) for which expected listing fees will be retrieved. The user passes in one or more offerId values (a maximum of 250). See the <a href="https://pages.ebay.com/help/sell/fees.html " target="_blank">Standard selling fees help page for more information on listing fees.