OperatingHours

Struct OperatingHours 

pub struct OperatingHours {
    pub day_of_week_enum: Option<String>,
    pub intervals: Option<Vec<Interval>>,
}
OperatingHours : This type is used to express the regular operating hours of a merchant’s store or fulfillment center during the days of the week.

Fields

day_of_week_enum: Option<String>

A dayOfWeekEnum value is required for each day of the week that the store location has regular operating hours.

This field is returned if operating hours are defined for the store location. For implementation help, refer to eBay API documentation

intervals: Option<Vec<Interval>>

This container is used to define the opening and closing times of a store location’s working day (defined in the dayOfWeekEnum field). An intervals container is needed for each day of the week that the store location is open. If a store location closes for lunch (or any other period during the day) and then reopens, multiple open and close pairs are needed

This container is returned if operating hours are defined for the store location.

Implementations

Source

impl OperatingHours

pub fn new() -> OperatingHours

This type is used to express the regular operating hours of a merchant’s store or fulfillment center during the days of the week.