Specification

Struct Specification 

pub struct Specification {
    pub name: Option<String>,
    pub values: Option<Vec<String>>,
}
Specification : This type is used to specify product aspects for which variations within an inventory item group vary, and the order in which they appear in the listing. For example, t-shirts in an inventory item group may be available in multiple sizes and colors.

Fields

name: Option<String>

This is the name of product variation aspect. Typically, for clothing, typical aspect names are "Size" and "Color". Product variation aspects are not required immediately upon creating an inventory item group, but these aspects will be required before a multiple-variation listing containing this inventory item group is published. For each product variation aspect that is specified through the specifications container, one name value is required and two or more variations of this aspect are required through the values array.

<span class="tablenote"> Note: Each member of the inventory item group should have these same aspect names specified through the product.aspects container when the inventory item is created with the createOrReplaceInventoryItem or bulkCreateOrReplaceInventoryItem call.
<div class="msgbox_important"><p class="msgbox_importantInDiv" data-mc-autonum="<b><span style="color: #dd1e31;" class="mcFormatColor">Important! </span></b>"><span class="autonumber"><span style="color: #dd1e31;" class="mcFormatColor">Important!Publish offer note: This field is required before an offer can be published to create an active listing.


Max Length: 40

values: Option<Vec<String>>

This is an array of values pertaining to the corresponding product variation aspect (specified in the name field). Below is a sample of how these values will appear under a specifications container:

"specifications": [{
"name": "Size",
"values": ["Small",
"Medium",
"Large"]
},
{
"name": "Color",
"values": ["Blue",
"White",
"Red"]
}]
<span class="tablenote"> Note: Each member of the inventory item group should have these same aspect names, and each individual inventory item should have each variation of the product aspect values specified through the product.aspects container when the inventory item is created with the createOrReplaceInventoryItem or bulkCreateOrReplaceInventoryItem call.
<div class="msgbox_important"><p class="msgbox_importantInDiv" data-mc-autonum="<b><span style="color: #dd1e31;" class="mcFormatColor">Important! </span></b>"><span class="autonumber"><span style="color: #dd1e31;" class="mcFormatColor">Important!Publish offer note: This array is required and at least one value that matches the corresponding aspect name must be specified.


Max Length: 50

Implementations

Source

impl Specification

pub fn new() -> Specification

This type is used to specify product aspects for which variations within an inventory item group vary, and the order in which they appear in the listing. For example, t-shirts in an inventory item group may be available in multiple sizes and colors.