pub struct MultiCompatibilityPropertyValuesResponse {
pub compatibilities: Option<Vec<Compatibility>>,
pub metadata_version: Option<String>,
}Expand description
MultiCompatibilityPropertyValuesResponse : This type defines the response fields for the getMultiCompatibilityPropertyValues method.
Fields
compatibilities: Option<Vec<Compatibility>>This container defines the compatibility details associated with the specified property name value(s).
metadata_version: Option<String>The version number of the metadata. This version is upticked whenever there are compatibility name changes for the specified marketplace.
Implementations
Sourceimpl MultiCompatibilityPropertyValuesResponse
impl MultiCompatibilityPropertyValuesResponse
Sourcepub fn new() -> MultiCompatibilityPropertyValuesResponse
pub fn new() -> MultiCompatibilityPropertyValuesResponse
This type defines the response fields for the getMultiCompatibilityPropertyValues method.