pub struct PropertyNamesRequest {
pub category_id: Option<String>,
pub dataset: Option<Vec<String>>,
}Expand description
PropertyNamesRequest : This type defines the request fields for the getCompatibilityPropertyNames method.
Fields
category_id: Option<String>The unique identifier of the eBay leaf category for which to retrieve compatibility property names. This category must be a valid eBay category on the specified eBay marketplace, and the category must support parts compatibility.
Use the <a href="/api-docs/sell/metadata/resources/marketplace/methods/getAutomotivePartsCompatibilityPolicies" target="_blank ">getAutomotivePartsCompatibilityPolicies method to retrieve a list of categories that support parts compatibility.
dataset: Option<Vec<String>>This array defines the properties that will be returned for the compatibility-enabled category.
For example, if you specify Searchable, the compatibility details will contain properties that can be used to search for products, such as make or model.
Valid values:
DisplayableProductDetails: Properties for use in a user interface to describe products.DisplayableSearchResults: Properties for use in results for product searches.Searchable: Properties for use in searches.Sortable: Properties that are suitable for sorting.
DisplayableSearchResults
Implementations
Sourceimpl PropertyNamesRequest
impl PropertyNamesRequest
Sourcepub fn new() -> PropertyNamesRequest
pub fn new() -> PropertyNamesRequest
This type defines the request fields for the getCompatibilityPropertyNames method.