pub struct PropertyNamesResponsePropertyNames {
pub property_display_name: Option<String>,
pub property_name: Option<String>,
pub property_name_metadata: Option<Box<PropertyNamesResponsePropertyNameMetadata>>,
}Expand description
PropertyNamesResponsePropertyNames : This type defines the fields associated with a property name.
Fields
property_display_name: Option<String>The display name of a property. This is the localized name of the compatible property.
property_name: Option<String>The canonical name of a property. This value is used as part of the name-value pairs used to specify compatibility.
property_name_metadata: Option<Box<PropertyNamesResponsePropertyNameMetadata>>Implementations
Sourceimpl PropertyNamesResponsePropertyNames
impl PropertyNamesResponsePropertyNames
Sourcepub fn new() -> PropertyNamesResponsePropertyNames
pub fn new() -> PropertyNamesResponsePropertyNames
This type defines the fields associated with a property name.