PropertyValues

Struct PropertyValues 

pub struct PropertyValues {
    pub property_name: Option<String>,
    pub property_value: Option<String>,
}
PropertyValues : This type defines the name-value pair associated with a property value.

Fields

property_name: Option<String>

The name of the property.

For example, typical vehicle property names are ‘Make’, ‘Model’, ‘Year’, ‘Engine’, and ‘Trim’, but will vary based on the eBay marketplace and the eBay category.

property_value: Option<String>

The value for the property specified in the properyName field.

For example, if the propertyName is make, then the propertyValue will be the specific make of the vehicle, such as Toyota.

Implementations

Source

impl PropertyValues

pub fn new() -> PropertyValues

This type defines the name-value pair associated with a property value.