PropertyValuesRequest

Struct PropertyValuesRequest 

pub struct PropertyValuesRequest {
    pub category_id: Option<String>,
    pub property_filters: Option<Vec<PropertyFilterInner>>,
    pub property_name: Option<String>,
    pub sort_order: Option<String>,
}
PropertyValuesRequest : This type defines the request fields used in the getCompatibilityPropertyValues method.

Fields

category_id: Option<String>

The unique identifier of the eBay leaf category for which to retrieve compatibility property values. This category must be a valid eBay category on the specified eBay marketplace, and the category must support parts compatibility.

Use the <a href="/api-docs/sell/metadata/resources/marketplace/methods/getAutomotivePartsCompatibilityPolicies" target="_blank ">getAutomotivePartsCompatibilityPolicies method to retrieve a list of categories that support parts compatibility.

property_filters: Option<Vec<PropertyFilterInner>>

This array can be used to specify the compatibility properties used limit the result set. Only values associated with the specified name-value pairs will be returned in the response.

For example, if the propertyName is set to Make and the propertyValue is set to Honda, only compatible Honda vehicles will be returned.

property_name: Option<String>

This field specifies the name of the property for which to retrieve associated property values.

For example, typical vehicle property names are ‘Make’, ‘Model’, ‘Year’, ‘Engine’, and ‘Trim’, but will vary based on the eBay marketplace and the eBay category. Use the <a href="/api-docs/sell/metadata/resources/compatibilities/methods/getCompatibilityPropertyNames" target="_blank ">getCompatibilityPropertyNames method to retrieve valid property names for a specified category.

sort_order: Option<String>

This field specifies the sort order for the property values in the result set.

Valid values:

  • Ascending
  • Descending
<span class="tablenote">Note: If no search order is specified, values are sorted in ascending order.

Implementations

Source

impl PropertyValuesRequest

pub fn new() -> PropertyValuesRequest

This type defines the request fields used in the getCompatibilityPropertyValues method.