pub struct SortOrderInner {
pub sort_order: Option<Box<SortOrderProperties>>,
pub sort_priority: Option<String>,
}Expand description
SortOrderInner : This type is used to provide the sort order of compatibility properties returned in the response.
Fields
sort_order: Option<Box<SortOrderProperties>>sort_priority: Option<String>The priority of the specified sort order provided.
For example, when a property is assigned Sort1, its values are sorted first. Values for the property assigned Sort2 are sorted second, and so on.
Valid values:
Sort1Sort2Sort3Sort4Sort5
Implementations
Sourceimpl SortOrderInner
impl SortOrderInner
Sourcepub fn new() -> SortOrderInner
pub fn new() -> SortOrderInner
This type is used to provide the sort order of compatibility properties returned in the response.