SortOrderProperties

Struct SortOrderProperties 

pub struct SortOrderProperties {
    pub order: Option<String>,
    pub property_name: Option<String>,
}
SortOrderProperties : This type is used to define the property to be used in sorting.

Fields

order: Option<String>

Defines the order of the sort.

Valid values:

  • Ascending
  • Descending

property_name: Option<String>

The name of the searchable property to be used for sorting.

For example, typical vehicle property names are ‘Make’, ‘Model’, ‘Year’, ‘Engine’, and ‘Trim’, but will vary based on the eBay marketplace and the eBay category.

Implementations

Source

impl SortOrderProperties

pub fn new() -> SortOrderProperties

This type is used to define the property to be used in sorting.