pub struct AuthenticityVerificationProgram {
pub description: Option<String>,
pub outcome_reason: Option<String>,
pub status: Option<String>,
pub terms_web_url: Option<String>,
}Expand description
AuthenticityVerificationProgram : A type that provides the status and outcome of an order line item going through the Authenticity Guarantee verification process.
Fields
description: Option<String>An informational message that applies to the Authenticity Guarantee program.
outcome_reason: Option<String>An informational message regarding the authentication outcome of an Authenticity Guarantee verification inspection.
<span class="tablenote">Note: This field is conditionally returned when there is information that applies to the Authenticity Guarantee program.
status: Option<String>An enumerated value that indicates whether the order line item has passed or failed the Authenticity Guarantee verification inspection, or whether the inspection and/or results are still pending.
<span class="tablenote">Note: This field is conditionally returned when the purchase is complete.
Valid Values:
PENDINGPASSEDFAILEDINELIGIBLE
terms_web_url: Option<String>The terms and conditions that apply to the Authenticity Guarantee program.
Implementations
Sourceimpl AuthenticityVerificationProgram
impl AuthenticityVerificationProgram
Sourcepub fn new() -> AuthenticityVerificationProgram
pub fn new() -> AuthenticityVerificationProgram
A type that provides the status and outcome of an order line item going through the Authenticity Guarantee verification process.