pub struct CreateGuestCheckoutSessionRequestV2 {
pub contact_email: Option<String>,
pub line_item_inputs: Option<Vec<LineItemInput>>,
pub shipping_address: Option<Box<ShippingAddress>>,
}Expand description
CreateGuestCheckoutSessionRequestV2 : A type that defines the fields used to create an eBay guest checkout session.
Fields
contact_email: Option<String>The buyer’s email address.
line_item_inputs: Option<Vec<LineItemInput>>An array used to define the line item(s) and desired quantity for an eBay guest checkout session.
Maximum: 10 line items
shipping_address: Option<Box<ShippingAddress>>Implementations
Sourceimpl CreateGuestCheckoutSessionRequestV2
impl CreateGuestCheckoutSessionRequestV2
Sourcepub fn new() -> CreateGuestCheckoutSessionRequestV2
pub fn new() -> CreateGuestCheckoutSessionRequestV2
A type that defines the fields used to create an eBay guest checkout session.