Error

Struct Error 

pub struct Error {
    pub category: Option<String>,
    pub domain: Option<String>,
    pub error_id: Option<i32>,
    pub input_ref_ids: Option<Vec<String>>,
    pub long_message: Option<String>,
    pub message: Option<String>,
    pub output_ref_ids: Option<Vec<String>>,
    pub parameters: Option<Vec<ErrorParameter>>,
    pub subdomain: Option<String>,
}
Error : A type that defines the fields for the error messages.

Fields

category: Option<String>

This string value indicates the error category. There are three categories of errors: request errors, application errors, and system errors.

domain: Option<String>

The name of the primary system where the error occurred. This is relevant for application errors.

error_id: Option<i32>

A unique code that identifies the particular error or warning that occurred. Your application can use error codes as identifiers in your customized error-handling algorithms.

input_ref_ids: Option<Vec<String>>

An array of reference IDs that identify the specific request elements most closely associated to the error or warning, if any.

long_message: Option<String>

A detailed description of the condition that caused the error or warning, and information on what what must be done to correct the problem.

message: Option<String>

A description of the condition that caused the error or warning.

output_ref_ids: Option<Vec<String>>

An array of reference IDs that identify the specific response elements most closely associated to the error or warning, if any.

parameters: Option<Vec<ErrorParameter>>

An array of warning and error messages that return one or more variables contextual information about the error or warning. This is often the field or value that triggered the error or warning.

subdomain: Option<String>

The name of the subdomain in which the error or warning occurred.

Implementations

Source

impl Error

pub fn new() -> Error

A type that defines the fields for the error messages.