pub struct LegacyReference {
pub legacy_item_id: Option<String>,
pub legacy_order_id: Option<String>,
pub legacy_transaction_id: Option<String>,
}Expand description
LegacyReference : A type that defines the fields to support using the <a href="https://developer.ebay.com/devzone/post-order/index.html#callindex ">Post Order API for returns and cancellations.
Restriction: The Post Order API can be used only with eBay member checkouts.
Fields
legacy_item_id: Option<String>The legacy ID used to identify an item.
This is used by the Post Order API <a href="https://developer.ebay.com/Devzone/post-order/post-order_v2_return__post.html " target="_blank">Create Return Request method. This call initiates the item return process. For more information on how to use this field in the Post Order API, see <a href="/api-docs/buy/static/api-order.html#return-request">Create a return request in the Buy Integration Guide.
Restriction: The Post Order API can be used only with eBay member checkouts.
legacy_order_id: Option<String>The legacy ID of the order.
This is used by the Post Order API <a href="https://developer.ebay.com/Devzone/post-order/post-order_v2_cancellation__post.html " target="_blank">Submit Cancellation Request method. This method initiates the item cancellation process. For more information on how to use this field in the Post Order API, see <a href="/api-docs/buy/static/api-order.html#using">Using the Post Order API.
Restriction: The Post Order API can be used only with eBay member checkouts.
legacy_transaction_id: Option<String>The legacy ID of the transaction.
This is used by the Post Order API <a href="https://developer.ebay.com/devzone/post-order/post-order_v2_return__post.html " target="_blank">Create Return Request call. This call initiates the item return process. For more information on how to use this field in the Post Order API, see <a href="/api-docs/buy/static/api-order.html#using">Using the Post Order API in the Buy Integration Guide.
Restriction: The Post Order API can be used only with eBay member checkouts.
Implementations
Sourceimpl LegacyReference
impl LegacyReference
Sourcepub fn new() -> LegacyReference
pub fn new() -> LegacyReference
A type that defines the fields to support using the <a href="https://developer.ebay.com/devzone/post-order/index.html#callindex ">Post Order API for returns and cancellations.
Restriction: The Post Order API can be used only with eBay member checkouts.