GetCompatibilityPropertyValuesResponse

Struct GetCompatibilityPropertyValuesResponse 

pub struct GetCompatibilityPropertyValuesResponse {
    pub compatibility_property_values: Option<Vec<CompatibilityPropertyValue>>,
}
GetCompatibilityPropertyValuesResponse : The base response type of the getCompatibilityPropertyValues method.

Fields

compatibility_property_values: Option<Vec<CompatibilityPropertyValue>>

This array contains all compatible vehicle property values that match the specified eBay marketplace, specified eBay category, and filters in the request. If the compatibility_property parameter value in the request is ‘Trim’, each value returned in each value field will be a different vehicle trim, applicable to any filters that are set in the filter query parameter of the request, and also based on the eBay marketplace and category specified in the call request.

Implementations

Source

impl GetCompatibilityPropertyValuesResponse

pub fn new() -> GetCompatibilityPropertyValuesResponse

The base response type of the getCompatibilityPropertyValues method.