pub struct AvailabilityDistribution {
pub fulfillment_time: Option<Box<TimeDuration>>,
pub merchant_location_key: Option<String>,
pub quantity: Option<i32>,
}Expand description
AvailabilityDistribution : This type is used to set the available quantity of the inventory item at one or more warehouse locations.
Fields
fulfillment_time: Option<Box<TimeDuration>>merchant_location_key: Option<String>The unique identifier of an inventory location where quantity is available for the inventory item. This field is conditionally required to identify the inventory location that has quantity of the inventory item.
Use the <a href="/api-docs/sell/inventory/resources/location/methods/getInventoryLocations" target="_blank">getInventoryLocations method to retrieve merchant location keys.
quantity: Option<i32>The integer value passed into this field indicates the quantity of the inventory item that is available at this inventory location. This field is conditionally required.
Implementations
Sourceimpl AvailabilityDistribution
impl AvailabilityDistribution
Sourcepub fn new() -> AvailabilityDistribution
pub fn new() -> AvailabilityDistribution
This type is used to set the available quantity of the inventory item at one or more warehouse locations.