pub struct MultiCompatibilityPropertyValuesRequest {
pub category_id: Option<String>,
pub property_filters: Option<Vec<PropertyFilterInner>>,
pub property_names: Option<Vec<String>>,
}Expand description
MultiCompatibilityPropertyValuesRequest : This type defines the request fields used in the getMultiCompatibilityPropertyValues method.
Fields
category_id: Option<String>The unique identifier of the eBay leaf category for which to retrieve property values.
Use the <a href="/api-docs/sell/metadata/resources/marketplace/methods/getAutomotivePartsCompatibilityPolicies" target="_blank ">getAutomotivePartsCompatibilityPolicies method to retrieve a list of categories that support parts compatibility.
property_filters: Option<Vec<PropertyFilterInner>>This array can be used to specify the compatibility properties used to limit the result set. Only values associated with the specified name-value pairs will be returned in the response.
For example, if the propertyName is set to Year and the propertyValue is set to 2022, only compatible vehicles from 2022 will be returned.
At least one property name-value pair must be used.
property_names: Option<Vec<String>>This comma-delimited array specifies the names of the properties for which to retrieve associated property values.
For example, typical vehicle property names are ‘Make’, ‘Model’, ‘Year’, ‘Engine’, and ‘Trim’, but will vary based on the eBay marketplace and the eBay category.
Implementations
Sourceimpl MultiCompatibilityPropertyValuesRequest
impl MultiCompatibilityPropertyValuesRequest
Sourcepub fn new() -> MultiCompatibilityPropertyValuesRequest
pub fn new() -> MultiCompatibilityPropertyValuesRequest
This type defines the request fields used in the getMultiCompatibilityPropertyValues method.