pub struct PropertyFilterInner {
pub property_name: Option<String>,
pub property_value: Option<String>,
pub unit_of_measurement: Option<String>,
pub url: Option<String>,
}Expand description
PropertyFilterInner : This type is used to define the available compatibility property filters.
Fields
property_name: Option<String>The name of the property being described.
For example, typical vehicle property names are ‘Make’, ‘Model’, ‘Year’, ‘Engine’, and ‘Trim’, but will vary based on the eBay marketplace and the eBay category. Use the <a href="/api-docs/sell/metadata/resources/compatibilities/methods/getCompatibilityPropertyNames" target="_blank ">getCompatibilityPropertyNames method to retrieve valid property names for a specified category.
property_value: Option<String>The value for the property specified in the properyName field.
For example, if the propertyName is Make, then the propertyValue will be the specific make of the vehicle, such as Toyota. Use the <a href="/api-docs/sell/metadata/resources/compatibilities/methods/getCompatibilityPropertyValues" target="_blank ">getCompatibilityPropertyValues to retreive valid property values associated with a specified property name.
unit_of_measurement: Option<String>The unit of measurement of the property being described, if applicable.
url: Option<String>The URL associated with the property being described, if applicable.
Implementations
Sourceimpl PropertyFilterInner
impl PropertyFilterInner
Sourcepub fn new() -> PropertyFilterInner
pub fn new() -> PropertyFilterInner
This type is used to define the available compatibility property filters.