pub struct SpecificationRequest {
pub category_id: Option<String>,
pub compatibility_property_filters: Option<Vec<PropertyFilterInner>>,
pub dataset: Option<String>,
pub dataset_property_name: Option<Vec<String>>,
pub exact_match: Option<bool>,
pub pagination_input: Option<Box<PaginationInput>>,
pub sort_orders: Option<Vec<SortOrderInner>>,
pub specifications: Option<Vec<PropertyFilterInner>>,
}Expand description
SpecificationRequest : This type provides the properties and specifications to use to search for compatibilities.
Fields
category_id: Option<String>The unique identifier of the eBay leaf category for which compatibility details are being retrieved. This category must be a valid eBay category on the specified eBay marketplace, and the category must support parts compatibility for cars, trucks, or motorcycles.
Use the <a href="/api-docs/sell/metadata/resources/marketplace/methods/getAutomotivePartsCompatibilityPolicies" target="_blank ">getAutomotivePartsCompatibilityPolicies method to retrieve a list of categories that support parts compatibility by specification. For the categories in the response that support compatibility by specification, you’ll see SPECIFICATIONS as the value for the compatibilityBasedOn field
compatibility_property_filters: Option<Vec<PropertyFilterInner>>This comma-delimited array can be used to restrict the number of compatible application name-value pairs returned in the response by specifying the properties that the seller wishes to be included in the response.
Only compatible applications with the specified properties will be returned. Properties that can be specified here include make, model, year, and trim.
dataset: Option<String>This field can be used to define the type of properties that will be returned in the response.
For example, if you specify Searchable, the compatibility details will contain properties that can be used to search for products, such as make or model.
<span class="tablenote">Note: This field cannot be used alongside dataPropertyName. If both are used, an error will occur.
Valid values:
DisplayableProductDetails: Properties for use in a user interface to describe products.DisplayableSearchResults: Properties for use in results for product searches.Searchable: Properties for use in searches.Sortable: Properties that are suitable for sorting.
DisplayableSearchResults
dataset_property_name: Option<Vec<String>>This comma-delimited array can be used to define the specific property name(s) that will be returned in the response.
For example, if you specify Engine, the result set will only contain engines that are compatible with the input criteria.
<span class="tablenote">Note: This array cannot be used alongside dataset. If both are used, an error will occur.
exact_match: Option<bool>This boolean can be used to specify that the compatibilities returned in the response are to be defined by an exact match on the input value of specification properties.
By default, an expanded compatibility match is done when it applies, such as for Load Index, where a compatible vehicle is one that has a load index requirement that is less than or equal to the input. By specifying this field as true, only exact matches are returned.
pagination_input: Option<Box<PaginationInput>>sort_orders: Option<Vec<SortOrderInner>>This array specifies the sorting order of the compatibility properties. Any of the searchable properties can be used to specify search order. Up to 5 levels of sort order may be specified.
<span class="tablenote">Note: If no sort order is specified through this field, the default sort order of popularity descending is applied.
specifications: Option<Vec<PropertyFilterInner>>This array defines the specifications of the part, in the form of name-value pairs, for which compatible applications will be retrieved.
Implementations
Sourceimpl SpecificationRequest
impl SpecificationRequest
Sourcepub fn new() -> SpecificationRequest
pub fn new() -> SpecificationRequest
This type provides the properties and specifications to use to search for compatibilities.