pub struct CreateOffersRequest {
pub allow_counter_offer: Option<bool>,
pub message: Option<String>,
pub offer_duration: Option<Box<TimeDuration>>,
pub offered_items: Option<Vec<OfferedItem>>,
}Expand description
CreateOffersRequest : This complex type contains the fields needed to create an offer to a buyer that is initiated by the seller.
Fields
allow_counter_offer: Option<bool>If set to true, the buyer is allowed to make a counter-offer to the seller’s offer.
<span class="tablenote">Note: Currently, you must set this field to false; counter-offers are not supported in this release.
Default: false
message: Option<String>A seller-defined message related to the offer being made.
This message is sent to the list of "interested" buyers.
To increase the conversion rate of the offers a seller makes to buyers, eBay recommends you always add a customized message to your offers.
Maximum length: 2,000 characters
offer_duration: Option<Box<TimeDuration>>offered_items: Option<Vec<OfferedItem>>An array of objects where each object contains the details of an offer and the ID of the listing on which the offer is being made.
Note that the service does not currently support the creation of multiple offers with a single call to sendOfferToInterestedBuyer. With this, each request can target only one listing at a time and you must populate this array with a single element that contains the details of one offer.
Implementations
Sourceimpl CreateOffersRequest
impl CreateOffersRequest
Sourcepub fn new() -> CreateOffersRequest
pub fn new() -> CreateOffersRequest
This complex type contains the fields needed to create an offer to a buyer that is initiated by the seller.