pub struct GetCompatibilityPropertyValuesResponse {
pub compatibility_property_values: Option<Vec<CompatibilityPropertyValue>>,
}Expand description
GetCompatibilityPropertyValuesResponse : The base response type of the getCompatibilityPropertyValues method.
Fields
compatibility_property_values: Option<Vec<CompatibilityPropertyValue>>This array contains all compatible vehicle property values that match the specified eBay marketplace, specified eBay category, and filters in the request. If the compatibility_property parameter value in the request is ‘Trim’, each value returned in each value field will be a different vehicle trim, applicable to any filters that are set in the
Implementations
Sourceimpl GetCompatibilityPropertyValuesResponse
impl GetCompatibilityPropertyValuesResponse
Sourcepub fn new() -> GetCompatibilityPropertyValuesResponse
pub fn new() -> GetCompatibilityPropertyValuesResponse
The base response type of the getCompatibilityPropertyValues method.